import { Injectable } from '@nestjs/common';
import { RabbitSubscribe } from '@mobicoop/message-broker-module';
import { CommandBus } from '@nestjs/cqrs';
import { CreateAdCommand } from '@modules/ad/core/application/commands/create-ad/create-ad.command';
import { Ad } from './ad.types';

@Injectable()
export class AdCreatedMessageHandler {
  constructor(private readonly commandBus: CommandBus) {}

  @RabbitSubscribe({
    name: 'adCreated',
  })
  public async adCreated(message: string) {
    try {
      const createdAd: Ad = JSON.parse(message);
      await this.commandBus.execute(
        new CreateAdCommand({
          id: createdAd.id,
          driver: createdAd.driver,
          passenger: createdAd.passenger,
          frequency: createdAd.frequency,
          fromDate: createdAd.fromDate,
          toDate: createdAd.toDate,
          schedule: createdAd.schedule,
          seatsProposed: createdAd.seatsProposed,
          seatsRequested: createdAd.seatsRequested,
          strict: createdAd.strict,
          waypoints: createdAd.waypoints,
        }),
      );
    } catch (e: any) {}
  }
}
