import {
  ArgumentInvalidException,
  ArgumentOutOfRangeException,
  ValueObject,
} from '@mobicoop/ddd-library';

/** Note:
 * Value Objects with multiple properties can contain
 * other Value Objects inside if needed.
 * */

export interface StepProps {
  lon: number;
  lat: number;
  duration: number;
  distance: number;
}

export class Step extends ValueObject<StepProps> {
  get lon(): number {
    return this.props.lon;
  }

  get lat(): number {
    return this.props.lat;
  }

  get duration(): number {
    return this.props.duration;
  }

  get distance(): number {
    return this.props.distance;
  }

  protected validate(props: StepProps): void {
    if (props.duration < 0)
      throw new ArgumentInvalidException(
        'duration must be greater than or equal to 0',
      );
    if (props.distance < 0)
      throw new ArgumentInvalidException(
        'distance must be greater than or equal to 0',
      );
    if (props.lon > 180 || props.lon < -180)
      throw new ArgumentOutOfRangeException('lon must be between -180 and 180');
    if (props.lat > 90 || props.lat < -90)
      throw new ArgumentOutOfRangeException('lat must be between -90 and 90');
  }
}
